import { BROWSER } from "esm-env";
import { writable } from "svelte/store";
import { defaultColors } from "./colors";
import { setThemeStore } from "./context";
import { defaultIcons } from "./icon";
export const themes = ['light', 'dark', 'system'];
export const defaultLabels = {
    light: 'Light',
    dark: 'Dark',
    system: 'System',
};
export function createThemeSwitcher(config) {
    const { key, colors, icons, labels } = { key: 'theme', colors: defaultColors, icons: defaultIcons, labels: defaultLabels, ...config };
    let theme = 'system';
    if (BROWSER) {
        const saved = localStorage.theme;
        if (saved === 'light' || saved === 'dark') {
            theme = saved;
        }
    }
    const { subscribe, set } = writable(theme);
    function setTheme(value) {
        // only update if valid, and it's changed
        if (themes.includes(value) && value !== theme) {
            theme = value;
            set(theme);
        }
    }
    const store = {
        subscribe,
        setTheme,
        colors,
        icons,
        labels,
    };
    setThemeStore(store);
    return store;
}
